@@ -3,7 +3,7 @@
 *
 *  @author Ippei UKAI <ippei_ukai@mac.com>
 *
-*  $Id: MyExternalCmdExecDialog.cpp 3613 2009-01-31 17:55:01Z harryvanderwolf $
+*  $Id: MyExternalCmdExecDialog.cpp 4211 2009-08-15 04:01:15Z gpatters1 $
 *
 *  This is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
@@ -587,6 +587,7 @@ MyExecDialog::MyExecDialog(wxWindow * parent, const wxString& title, const wxPoi
 
     wxBoxSizer * topsizer = new wxBoxSizer( wxVERTICAL );
     m_execPanel = new MyExecPanel(this);
+    m_cancelled = false;
     
     topsizer->Add(m_execPanel, 1, wxEXPAND | wxALL, 2);
 
@@ -604,11 +605,17 @@ MyExecDialog::MyExecDialog(wxWindow * parent, const wxString& title, const wxPoi
 void MyExecDialog::OnProcessTerminate(wxProcessEvent & event)
 {
     DEBUG_DEBUG("Process terminated with return code: " << event.GetExitCode());
-    EndModal(event.GetExitCode());
+    if (m_cancelled) {
+        EndModal(HUGIN_EXIT_CODE_CANCELLED);
+    } else {
+        EndModal(event.GetExitCode());
+    }
 }
 
 void MyExecDialog::OnCancel(wxCommandEvent& WXUNUSED(event))
 {
+    DEBUG_DEBUG("Cancel Pressed");
+    m_cancelled = true;
     m_execPanel->KillProcess();
 }
 
