@@ -3,7 +3,7 @@
 *
 *  @author Ippei UKAI <ippei_ukai@mac.com>
 *
-*  $Id: MyExternalCmdExecDialog.h 3479 2008-10-08 09:35:22Z dangelo $
+*  $Id: MyExternalCmdExecDialog.h 4211 2009-08-15 04:01:15Z gpatters1 $
 *
 *  This is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
@@ -27,6 +27,8 @@
 #ifndef _MYEXTERNALCMDEXECDIALOG__H
 #define _MYEXTERNALCMDEXECDIALOG__H
 
+const int HUGIN_EXIT_CODE_CANCELLED = -255;
+
 class MyExternalCmdExecDialog;
 class HuginPipedProcess;
 int MyExecuteCommandOnDialog(wxString command, wxString args, wxWindow* parent, wxString title);
@@ -158,6 +160,7 @@ public:
 private:
     
     MyExecPanel * m_execPanel;
+    bool m_cancelled;
 
     // any class wishing to process wxWidgets events must use this macro
     DECLARE_EVENT_TABLE()
