@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: AssistantPanel.cpp 3944 2009-06-17 05:34:34Z tmodes $
+ *  $Id: AssistantPanel.cpp 4362 2009-09-10 16:16:26Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -50,8 +50,8 @@
 #include "hugin/MainFrame.h"
 #include "hugin/huginApp.h"
 #include "hugin/AutoCtrlPointCreator.h"
-#include "base_wx/PTWXDlg.h"
 #include "hugin/TextKillFocusHandler.h"
+#include "base_wx/PTWXDlg.h"
 #include "hugin/PanoDruid.h"
 #include "base_wx/MyProgressDialog.h"
 #include "hugin/config_defaults.h"
@@ -398,7 +398,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
     wxString alignMsg;
     if (createCtrlP) {
         AutoCtrlPointCreator matcher;
-        CPVector cps = matcher.automatch(*m_pano, imgs, nFeatures,this);
+        CPVector cps = matcher.automatch(MainFrame::Get()->GetDefaultSetting(),*m_pano, imgs, nFeatures,this);
         GlobalCmdHist::getInstance().addCommand(
             new PT::AddCtrlPointsCmd(*m_pano, cps)
             );
@@ -412,13 +412,9 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
         DEBUG_TRACE("Running Celeste");
         progress.increaseProgress(1, std::wstring(wxString(_("Running Celeste")).wc_str(wxConvLocal)));
 
-        // set numeric locale to C, for correct number output
-        char * old_locale = setlocale(LC_NUMERIC,NULL);
-        setlocale(LC_NUMERIC,"C");
-
         // determine file name of SVM model file
         // get XRC path from application
-        wxString wxstrModelFileName = huginApp::Get()->GetXRCPath() + wxT("data/") + wxT(HUGIN_CELESTE_MODEL);
+        wxString wxstrModelFileName = huginApp::Get()->GetDataPath() + wxT(HUGIN_CELESTE_MODEL);
         // convert wxString to string
         string strModelFileName(wxstrModelFileName.mb_str(wxConvUTF8));
 		
@@ -517,10 +513,6 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
         }	
 
         MainFrame::Get()->SetStatusText(_(""),0);
-
-        // reset locale
-        setlocale(LC_NUMERIC,old_locale);
-
     }
     DEBUG_TRACE("Finished running Celeste");
 
@@ -721,7 +713,16 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
 
     // show preview frame
     wxCommandEvent dummy;
-    MainFrame::Get()->OnToggleGLPreviewFrame(dummy);
+    long preview=wxConfigBase::Get()->Read(wxT("/Assistant/PreviewWindow"),1l);
+    switch(preview)
+    {
+        case 1:   
+            MainFrame::Get()->OnToggleGLPreviewFrame(dummy); 
+            break;
+        case 2:
+            MainFrame::Get()->OnTogglePreviewFrame(dummy);
+            break;
+    };
 
     // enable stitch button
     m_createButton->Enable();
