@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: AutoCtrlPointCreator.cpp 3784 2009-04-12 09:14:45Z harryvanderwolf $
+ *  $Id: AutoCtrlPointCreator.cpp 4375 2009-09-11 12:47:31Z harryvanderwolf $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -48,11 +48,10 @@
 #include <wx/utils.h>
 #include <wx/cmdline.h>
 
-#define MAC_AUTOPANO_PLUGIN (defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE)
 
-#if MAC_AUTOPANO_PLUGIN 
-#include <wx/dir.h>
-#include <CoreFoundation/CFBundle.h>
+#if defined MAC_SELF_CONTAINED_BUNDLE
+  #include <wx/dir.h>
+  #include <CoreFoundation/CFBundle.h>
 #endif
 
 using namespace std;
@@ -105,62 +104,36 @@ CPVector AutoCtrlPointCreator::readUpdatedControlPoints(const std::string & file
 }
 
 
-CPVector AutoCtrlPointCreator::automatch(Panorama & pano,
+CPVector AutoCtrlPointCreator::automatch(CPDetectorSetting &setting, 
+                                         Panorama & pano,
                                          const UIntSet & imgs,
                                          int nFeatures,
                                          wxWindow *parent)
 {
     CPVector cps;
-    int t = wxConfigBase::Get()->Read(wxT("/AutoPano/Type"),HUGIN_AP_TYPE);
-    if (t < 0) {
-
-        wxString tmp[2];
-    	tmp[0] = _("Autopano (version 1.03 or greater), from http://autopano.kolor.com");
-    	tmp[1] = _("Autopano-Sift, from http://user.cs.tu-berlin.de/~nowozin/autopano-sift/");
-    	// determine autopano type
-    	wxSingleChoiceDialog d(parent,  _("Choose which autopano program should be used\n"), _("Select autopano type"),
-	   	 	       2, tmp, NULL);
-        
-        if (d.ShowModal() == wxID_OK) {
-            t = d.GetSelection();
-        } else {
-            return cps;
-        }
-    }
-    
-#ifdef __WXMAC__
-    if(t==0)
-    {
-        if(wxMessageBox(_("Autopano from http://autopano.kolor.com is not available for OSX"), 
-                        _("Would you like to use Autopano-Sift instead?"),
-                        wxOK|wxCANCEL|wxICON_EXCLAMATION, parent)
-           == wxOK) t=1;
-        else return cps;
-    }
-#endif
+    int t = setting.GetType();
     switch (t) {
 	case 0:
 	{
 	    // autopano@kolor
 	    AutoPanoKolor matcher;
-	    cps = matcher.automatch(pano, imgs, nFeatures, parent);
+	    cps = matcher.automatch(setting, pano, imgs, nFeatures, parent);
 	    break;
 	}
 	case 1:
 	{
 	    // autopano-sift
 	    AutoPanoSift matcher;
-	    cps = matcher.automatch(pano, imgs, nFeatures, parent);
+	    cps = matcher.automatch(setting, pano, imgs, nFeatures, parent);
 	    break;
 	}
 	default:
 	    DEBUG_ERROR("Invalid autopano type");
     }
-    wxConfigBase::Get()->Write(wxT("/AutoPano/Type"),t);
     return cps;
 }
 
-CPVector AutoPanoSift::automatch(Panorama & pano, const UIntSet & imgs,
+CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, Panorama & pano, const UIntSet & imgs,
                                      int nFeatures, wxWindow *parent)
 {
     CPVector cps;
@@ -169,14 +142,11 @@ CPVector AutoPanoSift::automatch(Panorama & pano, const UIntSet & imgs,
     }
     // create suitable command line..
 
-    bool customAutopanoExe = HUGIN_APSIFT_EXE_CUSTOM;
-    wxConfigBase::Get()->Read(wxT("/AutoPanoSift/AutopanoExeCustom"), &customAutopanoExe);
-
 #if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
-    wxString autopanoExe = wxConfigBase::Get()->Read(wxT("/AutoPanoSift/AutopanoExe"), wxT(HUGIN_APSIFT_EXE));
-#if MAC_AUTOPANO_PLUGIN 
-    wxString autopanoArgs = wxConfigBase::Get()->Read(wxT("/AutoPanoSift/Args"),
-                                                      wxT(HUGIN_APSIFT_ARGS) );
+    bool customAutopanoExe = setting.GetCPDetectorExeCustom();
+    wxString autopanoExe = setting.GetProg();
+/*#if MAC_AUTOPANO_PLUGIN 
+    wxString autopanoArgs = setting.GetArgs();
 #endif
     
     if(!customAutopanoExe)
@@ -295,31 +265,30 @@ CPVector AutoPanoSift::automatch(Panorama & pano, const UIntSet & imgs,
             return cps;
         }
         
-    } else {
+    } else { */
         if(wxIsAbsolutePath(autopanoExe) && !wxFileExists(autopanoExe)) {
             wxMessageBox(wxT(""), _("Autopano-SIFT not found. Please specify a valid path in the preferences"), wxOK | wxICON_ERROR, parent);
             return cps;
         }
-    }
+/*    } */
 
 #elif defined __WXMSW__
-    wxString autopanoExe = wxConfigBase::Get()->Read(wxT("/AutoPanoSift/AutopanoExe"),wxT(HUGIN_APSIFT_EXE));
-    if (! customAutopanoExe) {
-        autopanoExe = wxT(HUGIN_APSIFT_EXE);
-    } else {
-        if(!wxFileExists(autopanoExe)) {
-            wxLogError(_("Autopano-SIFT not found. Please specify a valid path in the preferences"));
+    wxString autopanoExe = setting.GetProg();
+    wxFileName autopano(autopanoExe);
+    if(autopano.IsAbsolute())
+    {
+        if(!autopano.FileExists()) {
+            wxLogError(wxString::Format(_("\"%s\" not found. Please specify a valid path in the preferences"),autopanoExe));
             return cps;
         }
     }
 #else
     // autopano should be in the path on linux
-    wxString autopanoExe = wxConfigBase::Get()->Read(wxT("/AutoPanoSift/AutopanoExe"),wxT(HUGIN_APSIFT_EXE));
+    wxString autopanoExe = setting.GetProg();
 #endif
 
 #if !MAC_AUTOPANO_PLUGIN
-    wxString autopanoArgs = wxConfigBase::Get()->Read(wxT("/AutoPanoSift/Args"),
-                                                      wxT(HUGIN_APSIFT_ARGS));
+    wxString autopanoArgs = setting.GetArgs();
 #endif
     
 #ifdef __WXMSW__
@@ -471,24 +440,23 @@ CPVector AutoPanoSift::automatch(Panorama & pano, const UIntSet & imgs,
 }
 
 
-CPVector AutoPanoKolor::automatch(Panorama & pano, const UIntSet & imgs,
+CPVector AutoPanoKolor::automatch(CPDetectorSetting &setting, Panorama & pano, const UIntSet & imgs,
                               int nFeatures, wxWindow *parent)
 {
     CPVector cps;
 #ifdef __WXMSW__
-    wxString autopanoExe = wxConfigBase::Get()->Read(wxT("/AutoPanoKolor/AutopanoExe"), wxT(HUGIN_APKOLOR_EXE));
+    wxString autopanoExe = setting.GetProg();
     if(!wxFileExists(autopanoExe)) {
-        wxLogError(_("autopano.exe not found. Please specify a valid path in the preferences"));
+        wxLogError(wxString::Format(_("%s not found. Please specify a valid path in the preferences"),autopanoExe));
         return cps;
     }
 #else
     // todo: selection of autopano on linux..
-    wxString autopanoExe = wxConfigBase::Get()->Read(wxT("/AutoPanoKolor/AutopanoExe"),wxT(HUGIN_APKOLOR_EXE));
+    wxString autopanoExe = setting.GetProg();
 #endif
 
     // write default autopano.kolor.com flags
-    wxString autopanoArgs = wxConfigBase::Get()->Read(wxT("/AutoPanoKolor/Args"),
-                                                      wxT(HUGIN_APKOLOR_ARGS));
+    wxString autopanoArgs = setting.GetArgs();
 
     // build a list of all image files, and a corrosponding connection map.
     // local img nr -> global (panorama) img number
@@ -544,7 +512,9 @@ CPVector AutoPanoKolor::automatch(Panorama & pano, const UIntSet & imgs,
     // use MyExternalCmdExecDialog
     ret = MyExecuteCommandOnDialog(autopanoExe, autopanoArgs, parent, _("finding control points"));
 
-    if (ret == -1) {
+    if (ret == HUGIN_EXIT_CODE_CANCELLED) {
+        return cps;
+    } else if (ret == -1) {
         wxMessageBox( _("Could not execute command: " + cmd), _("wxExecute Error"),
                       wxOK | wxICON_ERROR, parent);
         return cps;
