@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: CPListFrame.cpp 3235 2008-07-25 02:40:47Z gpatters1 $
+ *  $Id: CPListFrame.cpp 3783 2009-04-09 06:07:38Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -272,27 +272,27 @@ CPListFrame::CPListFrame(MainFrame * parent, Panorama & pano)
     this->SetBackgroundColour(XRCCTRL(*this, "cp_list_select", wxButton)->GetBackgroundColour());
 #endif
 #ifdef __WXMSW__
-    wxIcon myIcon(MainFrame::Get()->GetXRCPath() + wxT("data/icon.ico"),wxBITMAP_TYPE_ICO);
+    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/icon.ico"),wxBITMAP_TYPE_ICO);
 #else
-    wxIcon myIcon(MainFrame::Get()->GetXRCPath() + wxT("data/icon.png"),wxBITMAP_TYPE_PNG);
+    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/icon.png"),wxBITMAP_TYPE_PNG);
 #endif
     SetIcon(myIcon);
 
     if (m_verbose) {
         // setup list display
         m_list->InsertColumn( 0, _("#"), wxLIST_FORMAT_RIGHT, 25);
-        m_list->InsertColumn( 1, _("left Img."), wxLIST_FORMAT_RIGHT, 65);
+        m_list->InsertColumn( 1, _("Left Img."), wxLIST_FORMAT_RIGHT, 65);
         m_list->InsertColumn( 2, _("x"), wxLIST_FORMAT_RIGHT, 40);
         m_list->InsertColumn( 3, _("y"), wxLIST_FORMAT_RIGHT, 40);
-        m_list->InsertColumn( 4, _("right Img."), wxLIST_FORMAT_RIGHT, 65);
+        m_list->InsertColumn( 4, _("Right Img."), wxLIST_FORMAT_RIGHT, 65);
         m_list->InsertColumn( 5, _("x"), wxLIST_FORMAT_RIGHT, 40);
         m_list->InsertColumn( 6, _("y"), wxLIST_FORMAT_RIGHT, 40);
         m_list->InsertColumn( 7, _("Alignment"), wxLIST_FORMAT_LEFT, 80);
         m_list->InsertColumn( 8, _("Distance"), wxLIST_FORMAT_RIGHT, 80);
     } else {
         m_list->InsertColumn( 0, _("G CP#"), wxLIST_FORMAT_RIGHT, 25);
-        m_list->InsertColumn( 1, _("left Img."), wxLIST_FORMAT_RIGHT, 65);
-        m_list->InsertColumn( 2, _("right Img."), wxLIST_FORMAT_RIGHT, 65);
+        m_list->InsertColumn( 1, _("Left Img."), wxLIST_FORMAT_RIGHT, 65);
+        m_list->InsertColumn( 2, _("Right Img."), wxLIST_FORMAT_RIGHT, 65);
         m_list->InsertColumn( 3, _("P CP#"), wxLIST_FORMAT_RIGHT, 25);
         m_list->InsertColumn( 4, _("Alignment"), wxLIST_FORMAT_LEFT, 80);
         m_list->InsertColumn( 5, _("Distance"), wxLIST_FORMAT_RIGHT, 80);
