@@ -52,11 +52,7 @@
 */
 
 extern "C" {
-#ifdef HasPANO13
 #include <pano13/queryfeature.h>
-#else
-#include <pano12/queryfeature.h>
-#endif
 }
 
 #include "PreviewToolHelper.h"
@@ -66,6 +62,7 @@ extern "C" {
 #include "PreviewIdentifyTool.h"
 #include "PreviewDifferenceTool.h"
 #include "PreviewPanoMaskTool.h"
+#include "PreviewControlPointTool.h"
 
 using namespace utils;
 
@@ -97,6 +94,7 @@ BEGIN_EVENT_TABLE(GLPreviewFrame, wxFrame)
     EVT_TOOL(XRCID("preview_crop_tool"), GLPreviewFrame::OnCrop)
     EVT_TOOL(XRCID("preview_drag_tool"), GLPreviewFrame::OnDrag)
     EVT_TOOL(XRCID("preview_identify_tool"), GLPreviewFrame::OnIdentify)
+    EVT_TOOL(XRCID("preview_control_point_tool"), GLPreviewFrame::OnControlPoint)
     
     EVT_TEXT_ENTER( -1 , GLPreviewFrame::OnTextCtrlChanged)
 
@@ -153,7 +151,8 @@ GLPreviewFrame::GLPreviewFrame(wxFrame * frame, PT::Panorama &pano)
     DEBUG_ASSERT(crop_tool_id != -2);
     identify_tool_id = wxXmlResource::Get()->GetXRCID(wxT("preview_identify_tool"));
     DEBUG_ASSERT(identify_tool_id != -2);
-    
+    control_point_tool_id = wxXmlResource::Get()->GetXRCID(wxT("preview_control_point_tool"));
+    DEBUG_ASSERT(control_point_tool_id != -2);
 
     m_topsizer = new wxBoxSizer( wxVERTICAL );
 
@@ -234,7 +233,6 @@ GLPreviewFrame::GLPreviewFrame(wxFrame * frame, PT::Panorama &pano)
                                       wxDefaultPosition, wxDefaultSize);
 
     /* populate with all available projection types */
-#ifdef HasPANO13
     int nP = panoProjectionFormatCount();
     for(int n=0; n < nP; n++) {
         pano_projection_features proj;
@@ -243,23 +241,6 @@ GLPreviewFrame::GLPreviewFrame(wxFrame * frame, PT::Panorama &pano)
             m_ProjectionChoice->Append(wxGetTranslation(str2));
         }
     }
-#else
-    bool ok = true;
-    int n=0;
-    while(ok) {
-        char name[20];
-        char str[255];
-        sprintf(name,"PanoType%d",n);
-        n++;
-        int len = queryFeatureString(name,str,255);
-        if (len > 0) {
-            wxString str2(str, wxConvLocal);
-            m_ProjectionChoice->Append(wxGetTranslation(str2));
-        } else {
-            ok = false;
-        }
-    }
-#endif
     m_ProjectionChoice->SetSelection(2);
 
     blendModeSizer->Add(m_ProjectionChoice,
@@ -343,9 +324,6 @@ GLPreviewFrame::GLPreviewFrame(wxFrame * frame, PT::Panorama &pano)
 
     m_topsizer->Add(blendModeSizer, 0, wxEXPAND | wxALL, 5);
 
-    
-    
-#ifdef HasPANO13
     m_projParamSizer = new wxStaticBoxSizer(
     new wxStaticBox(this, -1, _("Projection Parameters")),
      wxHORIZONTAL);
@@ -380,8 +358,6 @@ GLPreviewFrame::GLPreviewFrame(wxFrame * frame, PT::Panorama &pano)
     // do not show projection param sizer
     m_topsizer->Show(m_projParamSizer, false, true);
 
-#endif
-
     wxConfigBase * config = wxConfigBase::Get();
 
     // add a status bar
@@ -519,7 +495,7 @@ void GLPreviewFrame::panoramaChanged(Panorama &pano)
     m_ToolBar->EnableTool(XRCID("preview_straighten_pano_tool"), pano.getNrOfImages() > 0);
 
     // TODO: enable display of parameters and set their limits, if projection has some.
-#ifdef HasPANO13
+
     int nParam = opts.m_projFeatures.numberOfParameters;
     bool relayout = false;
     // if the projection format has changed
@@ -560,7 +536,6 @@ void GLPreviewFrame::panoramaChanged(Panorama &pano)
     if (relayout) {
         m_topsizer->Layout();
     }
-#endif
     SetStatusText(wxString::Format(wxT("%.1f x %.1f"), opts.getHFOV(), opts.getVFOV()),2);
     m_HFOVSlider->SetValue(roundi(opts.getHFOV()));
     m_VFOVSlider->SetValue(roundi(opts.getVFOV()));
@@ -819,7 +794,6 @@ void GLPreviewFrame::OnTextCtrlChanged(wxCommandEvent & e)
             }
         }
         opts.outputExposureValue = p;
-#ifdef HasPANO13
     } else {
         int nParam = opts.m_projFeatures.numberOfParameters;
         std::vector<double> para = opts.getProjectionParameters();
@@ -838,7 +812,6 @@ void GLPreviewFrame::OnTextCtrlChanged(wxCommandEvent & e)
             }
         }
         opts.setProjectionParameters(para);
-#endif
     }
     GlobalCmdHist::getInstance().addCommand(
             new PT::SetPanoOptionsCmd( m_pano, opts )
@@ -858,7 +831,6 @@ void GLPreviewFrame::OnChangeFOV(wxScrollEvent & e)
         DEBUG_DEBUG("VFOV changed (slider): " << e.GetInt());
         opt.setVFOV(e.GetInt());
     } else {
-#ifdef HasPANO13
         int nParam = opt.m_projFeatures.numberOfParameters;
         std::vector<double> para = opt.getProjectionParameters();
         for (int i = 0; i < nParam; i++) {
@@ -870,7 +842,6 @@ void GLPreviewFrame::OnChangeFOV(wxScrollEvent & e)
         opt.setProjectionParameters(para);
 		opt.setHFOV(m_HFOVSlider->GetValue());
 		opt.setVFOV(m_VFOVSlider->GetValue());
-#endif
     }
 
     GlobalCmdHist::getInstance().addCommand(
@@ -889,7 +860,6 @@ void GLPreviewFrame::OnTrackChangeFOV(wxScrollEvent & e)
     } else if (e.GetEventObject() == m_VFOVSlider) {
         opt.setVFOV(e.GetInt());
     } else {
-#ifdef HasPANO13
         int nParam = opt.m_projFeatures.numberOfParameters;
         std::vector<double> para = opt.getProjectionParameters();
         for (int i = 0; i < nParam; i++) {
@@ -899,7 +869,6 @@ void GLPreviewFrame::OnTrackChangeFOV(wxScrollEvent & e)
             }
         }
         opt.setProjectionParameters(para);
-#endif
     }
     // we only actually update the panorama fully when the mouse is released.
     // As we are dragging it we don't want to create undo events, but we would
@@ -1047,6 +1016,7 @@ void GLPreviewFrame::MakeTools(PreviewToolHelper *helper_in)
     identify_tool = new PreviewIdentifyTool(helper, this);
     difference_tool = new PreviewDifferenceTool(helper);
     pano_mask_tool = new PreviewPanoMaskTool(helper);
+    control_point_tool = new PreviewControlPointTool(helper);
     
     // activate tools that are always active.
     helper->ActivateTool(pano_mask_tool);
@@ -1098,6 +1068,18 @@ void GLPreviewFrame::OnIdentify(wxCommandEvent & e)
     m_GLViewer->Refresh();
 }
 
+void GLPreviewFrame::OnControlPoint(wxCommandEvent & e)
+{
+    SetStatusText(wxT(""), 0); // blank status text as it refers to an old tool.
+    if (e.IsChecked())
+    {
+        TurnOffTools(helper->ActivateTool(control_point_tool));
+    } else {
+        helper->DeactivateTool(control_point_tool);
+    }
+    m_GLViewer->Refresh();
+}
+
 void GLPreviewFrame::TurnOffTools(std::set<PreviewTool*> tools)
 {
     std::set<PreviewTool*>::iterator i;
@@ -1122,6 +1104,12 @@ void GLPreviewFrame::TurnOffTools(std::set<PreviewTool*> tools)
             // cover up its indicators and restore normal button colours.
             m_GLViewer->Refresh();
             CleanButtonColours();
+        } else if (*i == control_point_tool)
+        {
+            // disabled the control point tool.
+            m_ToolBar->ToggleTool(control_point_tool_id, false);
+            // cover up the control point lines.
+            m_GLViewer->Refresh();
         }
     }
 }
