@@ -7,7 +7,7 @@
  *  @author Kai-Uwe Behrmann <web@tiscali.de> and
  *          Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: ImagesPanel.cpp 3906 2009-06-02 05:48:29Z tmodes $
+ *  $Id: ImagesPanel.cpp 4235 2009-08-17 03:19:23Z gpatters1 $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -28,6 +28,7 @@
 #include <config.h>
 #include "panoinc_WX.h"
 #include "panoinc.h"
+#include <time.h>
 
 #include "base_wx/platform.h"
 #include <vector>
@@ -130,6 +131,8 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     m_img_ctrls = XRCCTRL(*this, "image_control_panel", wxPanel);
     DEBUG_ASSERT(m_img_ctrls);
 
+    m_CPDetectorChoice = XRCCTRL(*this, "cpdetector_settings", wxChoice);
+
     // Image Preview
     m_smallImgCtrl = XRCCTRL(*this, "images_selected_image", wxStaticBitmap);
     DEBUG_ASSERT(m_smallImgCtrl);
@@ -142,9 +145,7 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
     m_empty.LoadFile(huginApp::Get()->GetXRCPath() +
                      wxT("data/") + wxT("druid.images.128.png"),
                      wxBITMAP_TYPE_PNG);
-    wxStaticBitmap * bmp = XRCCTRL(*this, "images_selected_image", wxStaticBitmap);
-    DEBUG_ASSERT(bmp);
-    bmp->SetBitmap(m_empty);
+    m_smallImgCtrl->SetBitmap(m_empty);
 
     wxListEvent ev;
     ListSelectionChanged(ev);
@@ -152,7 +153,15 @@ bool ImagesPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, co
 
 //    SetAutoLayout(false);
 
-    m_degDigits = wxConfigBase::Get()->Read(wxT("/General/DegreeFractionalDigitsEdit"),3);
+    wxConfigBase* config=wxConfigBase::Get();
+    m_degDigits = config->Read(wxT("/General/DegreeFractionalDigitsEdit"),3);
+    //read autopano generator settings
+    cpdetector_config.Read(config);
+    //write current autopano generator settings
+    cpdetector_config.Write(config);
+    config->Flush();
+    cpdetector_config.FillControl(m_CPDetectorChoice,true);
+    Layout();
 
     return true;
 }
@@ -273,7 +282,8 @@ void ImagesPanel::SIFTMatching(wxCommandEvent & e)
                             , wxSpinCtrl)->GetValue();
 
     AutoCtrlPointCreator matcher;
-    CPVector cps = matcher.automatch(*pano, selImg, nFeatures,this);
+    CPVector cps = matcher.automatch(cpdetector_config.settings[m_CPDetectorChoice->GetSelection()],
+        *pano, selImg, nFeatures,this);
     wxString msg;
     wxMessageBox(wxString::Format(_("Added %d control points"), cps.size()), _("Autopano result"),wxOK|wxICON_INFORMATION,this);
     GlobalCmdHist::getInstance().addCommand(
@@ -390,6 +400,7 @@ void ImagesPanel::ListSelectionChanged(wxListEvent & e)
     if (sel.size() == 0) {
         // nothing to edit
         DisableImageCtrls();
+        ClearImgExifInfo();
     } else {
         // enable edit
         EnableImageCtrls();
@@ -406,6 +417,7 @@ void ImagesPanel::ListSelectionChanged(wxListEvent & e)
             // multiselection, clear all values
             // we don't know which images parameters to show.
             ClearImgParameters();
+            ClearImgExifInfo();
             m_optAnchorButton->Disable();
             m_colorAnchorButton->Disable();
             m_moveDownButton->Disable();
@@ -423,8 +435,9 @@ void ImagesPanel::DisableImageCtrls()
     XRCCTRL(*this, "images_text_yaw", wxTextCtrl) ->Disable();
     XRCCTRL(*this, "images_text_roll", wxTextCtrl) ->Disable();
     XRCCTRL(*this, "images_text_pitch", wxTextCtrl) ->Disable();
-    XRCCTRL(*this, "images_selected_image", wxStaticBitmap)->
-    SetBitmap(m_empty);
+    m_smallImgCtrl->SetBitmap(m_empty);
+    m_smallImgCtrl->GetParent()->Layout();
+    m_smallImgCtrl->Refresh();
     m_optAnchorButton->Disable();
     m_colorAnchorButton->Disable();
     m_moveDownButton->Disable();
@@ -462,18 +475,104 @@ void ImagesPanel::ShowImgParameters(unsigned int imgNr)
     val = doubleToString(const_map_get(vars,"r").getValue(),m_degDigits);
     XRCCTRL(*this, "images_text_roll", wxTextCtrl) ->SetValue(wxString(val.c_str(), wxConvLocal));
 
+    ShowExifInfo(imgNr);
     ShowImage(imgNr);
 }
 
 
+void ImagesPanel::ShowExifInfo(unsigned int imgNr)
+{
+    SrcPanoImage img = pano->getSrcImage(imgNr);
+
+    double focalLength = 0;
+    double cropFactor = 0;
+    const bool applyExposureValue = FALSE;
+    initImageFromFile(img,focalLength,cropFactor,applyExposureValue);
+
+    std::string val;
+    wxString s;
+    val = img.getFilename();
+    XRCCTRL(*this, "images_filename",wxStaticText) ->
+        SetLabel(wxFileName(wxString(val.c_str(),HUGIN_CONV_FILENAME)).GetFullName());
+
+    val = img.getExifMake();
+    XRCCTRL(*this, "images_camera_make",wxStaticText) ->
+        SetLabel(wxString(val.c_str(),wxConvLocal));
+
+    val = img.getExifModel();
+    XRCCTRL(*this, "images_camera_model",wxStaticText) ->
+        SetLabel(wxString(val.c_str(),wxConvLocal));
+
+    struct tm exifdatetime;
+    if(img.getExifDateTime(&exifdatetime)==0)
+    {
+        wxDateTime s_datetime=wxDateTime(exifdatetime);
+        s=s_datetime.Format();
+    }
+    else
+        s = wxString(img.getExifDate().c_str(),wxConvLocal);
+    XRCCTRL(*this, "images_capture_date",wxStaticText)->SetLabel(s);
+
+    if(img.getExifFocalLength()>0.0)
+        if(img.getExifFocalLength35()>0.0)
+            s = wxString::Format(wxT("%0.1f mm (%0.0f mm)"),img.getExifFocalLength(),img.getExifFocalLength35());
+        else
+            s = wxString::Format(wxT("%0.1f mm"),img.getExifFocalLength());
+    else
+        s = wxEmptyString;
+    XRCCTRL(*this, "images_focal_length",wxStaticText)->SetLabel(s);
+
+    if(img.getExifAperture()>0)
+        s=wxString::Format(wxT("F%.1f"),img.getExifAperture());
+    else
+        s=wxEmptyString;
+    XRCCTRL(*this, "images_aperture",wxStaticText)->SetLabel(s);
+
+    if(img.getExifExposureTime()>0.5) 
+        if(img.getExifExposureTime()>=1.0) 
+            if(img.getExifExposureTime()>=10.0) 
+                s=wxString::Format(wxT("%3.0f s"),img.getExifExposureTime());
+            else
+                s=wxString::Format(wxT("%1.1f s"),img.getExifExposureTime());
+        else
+            s=wxString::Format(wxT("%1.2f s"),img.getExifExposureTime());
+    else {
+        if (img.getExifExposureTime() > 0) {
+            s=wxString::Format(wxT("1/%0.0f s"),1.0/img.getExifExposureTime());
+        } else {
+            //Sanity
+            s=wxT("");
+        }
+    }
+        
+    XRCCTRL(*this, "images_shutter_speed",wxStaticText)->SetLabel(s);
+
+    XRCCTRL(*this, "images_shutter_speed",wxStaticText)->GetParent()->Layout();
+    Refresh();
+}
+
+
 void ImagesPanel::ClearImgParameters()
 {
     XRCCTRL(*this, "images_text_yaw", wxTextCtrl) ->Clear();
     XRCCTRL(*this, "images_text_roll", wxTextCtrl) ->Clear();
     XRCCTRL(*this, "images_text_pitch", wxTextCtrl) ->Clear();
 
-    XRCCTRL(*this, "images_selected_image", wxStaticBitmap)->
-        SetBitmap(m_empty);
+    m_smallImgCtrl->SetBitmap(m_empty);
+    m_smallImgCtrl->GetParent()->Layout();
+    m_smallImgCtrl->Refresh();
+    ClearImgExifInfo();
+}
+
+void ImagesPanel::ClearImgExifInfo()
+{
+    XRCCTRL(*this, "images_filename", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_camera_make", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_camera_model", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_capture_date", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_focal_length", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_aperture", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_shutter_speed", wxStaticText) ->SetLabel(wxT(""));
 }
 
 
@@ -509,6 +608,7 @@ void ImagesPanel::UpdatePreviewImage()
     }
     wxImage scaled = img.Scale(sz.GetWidth(),sz.GetHeight());
     m_smallImgCtrl->SetBitmap(wxBitmap(scaled));
+    m_smallImgCtrl->GetParent()->Layout();
     m_smallImgCtrl->Refresh();
 }
 
@@ -697,6 +797,15 @@ void ImagesPanel::OnMoveImageUp(wxCommandEvent & e)
     }
 }
 
+void ImagesPanel::ReloadCPDetectorSettings()
+{
+    cpdetector_config.Read(); 
+    cpdetector_config.FillControl(m_CPDetectorChoice,true);
+    m_CPDetectorChoice->InvalidateBestSize();
+    m_CPDetectorChoice->GetParent()->Layout();
+    Refresh();
+};
+
 IMPLEMENT_DYNAMIC_CLASS(ImagesPanel, wxPanel)
 
 ImagesPanelXmlHandler::ImagesPanelXmlHandler()
@@ -741,19 +850,16 @@ void ImagesPanel::OnCelesteButton(wxCommandEvent & e)
         ProgressReporterDialog progress(selImg.size()+1, _("Running Celeste"), _("Running Celeste"),this);
 
         DEBUG_TRACE("Running Celeste");
-        // set numeric locale to C, for correct number output
-        char * old_locale = setlocale(LC_NUMERIC,NULL);
-        setlocale(LC_NUMERIC,"C");
 
         // determine file name of SVM model file
         // get XRC path from application
-        wxString wxstrModelFileName = huginApp::Get()->GetXRCPath() + wxT("data/") + wxT(HUGIN_CELESTE_MODEL);
+        wxString wxstrModelFileName = huginApp::Get()->GetDataPath() + wxT(HUGIN_CELESTE_MODEL);
         // convert wxString to string
         string strModelFileName(wxstrModelFileName.mb_str(wxConvUTF8));
 		
         // SVM model file
         if (! wxFile::Exists(wxstrModelFileName) ) {
-            wxMessageBox(_("Celeste model file not found, Hugin needs to be properly installed." ), _("Fatal Error"));
+            wxMessageBox(_("Celeste model expected in ") + wxstrModelFileName +_(" not found, Hugin needs to be properly installed." ), _("Fatal Error"));
             return ;
         }
 
@@ -853,8 +959,6 @@ void ImagesPanel::OnCelesteButton(wxCommandEvent & e)
         }
         MainFrame::Get()->SetStatusText(_(""),0);
 
-        // reset locale
-        setlocale(LC_NUMERIC,old_locale);	
     }
 
     wxMessageBox(wxString::Format(_("Removed %d control points"), total_removed), _("Celeste result"),wxOK|wxICON_INFORMATION,this);
