@@ -3,7 +3,7 @@
  *
  *  @author Kai-Uwe Behrmann <web@tiscali.de>
  *
- *  $Id: ImagesPanel.h 3502 2008-10-13 23:33:00Z blimbo $
+ *  $Id: ImagesPanel.h 4090 2009-07-23 05:22:55Z tmodes $
  *
  *  This is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -81,7 +81,10 @@ public:
      */
 //    virtual void panoramaChanged(PT::Panorama &pano);
     void panoramaImagesChanged(PT::Panorama &pano, const PT::UIntSet & imgNr);
-
+    /** Reloads the cp detector settings from config, necessary after edit preferences */
+    void ReloadCPDetectorSettings();
+    /** returns the default cp detector setings */
+    CPDetectorSetting& GetDefaultSetting() { return cpdetector_config.settings.Item(cpdetector_config.GetDefaultGenerator());};
 private:
     // a window event
     void OnSize(wxSizeEvent & e);
@@ -141,6 +144,8 @@ private:
 
     /** show a bigger thumbnail */
     void ShowImage(unsigned int imgNr);
+    void ShowExifInfo(unsigned int imgNr);
+    void ClearImgExifInfo();
     void UpdatePreviewImage();
 
     /** bitmap with default image */
@@ -160,6 +165,9 @@ private:
     wxButton * m_removeCPButton;
 
     wxPanel *m_img_ctrls;
+    wxChoice *m_CPDetectorChoice;
+    //storing for different cp detector settings
+    CPDetectorConfig cpdetector_config;
 
     int m_degDigits;
 
