@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: MainFrame.cpp 3891 2009-05-29 05:23:39Z tmodes $
+ *  $Id: MainFrame.cpp 4315 2009-09-03 01:00:39Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -210,9 +210,9 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
             int tw, th;
             wxString version;
 #ifdef HUGIN_DEVELOPMENT_VERSION
-            version.Printf(_("Prerelease %s"),wxString(PACKAGE_VERSION, wxConvLocal).c_str());
+            version.Printf(_("Prerelease %s"),wxString(DISPLAY_VERSION, wxConvLocal).c_str());
 #else
-            version.Printf(_("Version %s"),wxString(PACKAGE_VERSION, wxConvLocal).c_str());
+            version.Printf(_("Version %s"),wxString(DISPLAY_VERSION, wxConvLocal).c_str());
 #endif
             dc.GetTextExtent(version, &tw, &th);
             // place text on bitmap.
@@ -561,10 +561,10 @@ void MainFrame::OnSaveProject(wxCommandEvent & e)
                                                               makefile,
                                                               tmpDir);
         }
+        SetStatusText(wxString::Format(_("saved project %s"), m_filename.c_str()),0);
+        this->SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Tools Frontend"));
+        pano.clearDirty();
     }
-    SetStatusText(wxString::Format(_("saved project %s"), m_filename.c_str()),0);
-    this->SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - hugin"));
-    pano.clearDirty();
     } catch (std::exception & e) {
         wxString err(e.what(), wxConvLocal);
         wxMessageBox(err, wxT("Exception during saving project file"));
@@ -653,7 +653,7 @@ void MainFrame::LoadProjectFile(const wxString & filename)
         DEBUG_DEBUG("project contains " << pano.getNrOfImages() << " after load");
         opt_panel->setModeCustom();
         SetStatusText(_("Project opened"));
-        this->SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - hugin"));
+        this->SetTitle(fname.GetName() + wxT(".") + fname.GetExt() + wxT(" - ") + _("Hugin - Panorama Tools Frontend"));
         if (! (fname.GetExt() == wxT("pto"))) {
             // do not remember filename if its not a hugin project
             // to avoid overwriting the original project with an
@@ -737,14 +737,19 @@ void MainFrame::OnNewProject(wxCommandEvent & e)
     GlobalCmdHist::getInstance().addCommand( new NewPanoCmd(pano));
     // remove old images from cache
     ImageCache::getInstance().flush();
-    this->SetTitle(wxT("hugin"));
+    this->SetTitle(_("Hugin - Panorama Tools Frontend"));
     pano.clearDirty();
 
     // Setup pano with options from preferences
     PanoramaOptions opts = pano.getOptions();
     wxConfigBase* config = wxConfigBase::Get();
+    opts.outputFormat = PanoramaOptions::TIFF;
+    opts.blendMode = PanoramaOptions::ENBLEND_BLEND;
     opts.enblendOptions = config->Read(wxT("Enblend/Args"),wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
     opts.enfuseOptions = config->Read(wxT("Enfuse/Args"),wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
+	opts.interpolator = (vigra_ext::Interpolator)config->Read(wxT("Nona/Interpolator"),HUGIN_NONA_INTERPOLATOR);
+	opts.remapUsingGPU = (bool)config->Read(wxT("Nona/useGPU"),HUGIN_NONA_USEGPU);
+	opts.tiff_saveROI = (bool)config->Read(wxT("Nona/CroppedImages"),HUGIN_NONA_CROPPEDIMAGES);
     pano.setOptions(opts);
 
     wxCommandEvent dummy;
@@ -1159,6 +1164,7 @@ void MainFrame::OnShowPrefs(wxCommandEvent & e)
     pref_dlg->ShowModal();
     //update image cache size
     ImageCache::getInstance().SetUpperLimit(wxConfigBase::Get()->Read(wxT("/ImageCache/UpperBound"), HUGIN_IMGCACHE_UPPERBOUND));
+    images_panel->ReloadCPDetectorSettings();
 
 }
 
@@ -1510,6 +1516,11 @@ void MainFrame::OnSize(wxSizeEvent &e)
     e.Skip();
 }
 
+CPDetectorSetting& MainFrame::GetDefaultSetting()
+{
+    return images_panel->GetDefaultSetting(); 
+};
+
 void MainFrame::RestoreLayoutOnNextResize()
 {
     cout << "MainFrame::RestoreLayoutOnNextResize()" << endl;
