@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: OptimizePanel.cpp 3721 2009-03-11 21:48:19Z gkohlmeyer $
+ *  $Id: OptimizePanel.cpp 4362 2009-09-10 16:16:26Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -528,6 +528,11 @@ void OptimizePanel::runOptimizer(const UIntSet & imgs)
     }
     UIntSet allImg;
     fill_set(allImg,0, imgs.size()-1);
+
+    char *p = setlocale(LC_ALL,NULL);
+    char *oldlocale = strdup(p);
+    setlocale(LC_ALL,"C");
+
     if (mode == OPT_PAIRWISE) {
 
         std::set<std::string> optvars2;
@@ -597,6 +602,8 @@ void OptimizePanel::runOptimizer(const UIntSet & imgs)
 #endif
     }
 
+    setlocale(LC_ALL,oldlocale);
+    free(oldlocale);
     // calculate control point errors and display text.
     if (AskApplyResult(optPano)) {
         GlobalCmdHist::getInstance().addCommand(
