@@ -7,7 +7,7 @@
  *  @author Kai-Uwe Behrmann <web@tiscali.de> and
  *          Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PanoPanel.cpp 3809 2009-04-28 05:33:07Z tmodes $
+ *  $Id: PanoPanel.cpp 4389 2009-09-12 23:20:32Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -39,11 +39,7 @@
 #include "common/wxPlatform.h"
 
 extern "C" {
-#ifdef HasPANO13
 #include <pano13/queryfeature.h>
-#else
-#include <pano12/queryfeature.h>
-#endif
 }
 
 #include "hugin/RunStitcherFrame.h"
@@ -91,6 +87,7 @@ BEGIN_EVENT_TABLE(PanoPanel, wxPanel)
     EVT_CHECKBOX ( XRCID("pano_cb_ldr_output_layers"), PanoPanel::OnOutputFilesChanged)
     EVT_CHECKBOX ( XRCID("pano_cb_ldr_output_exposure_layers"), PanoPanel::OnOutputFilesChanged)
     EVT_CHECKBOX ( XRCID("pano_cb_ldr_output_exposure_blended"), PanoPanel::OnOutputFilesChanged)
+    EVT_CHECKBOX ( XRCID("pano_cb_ldr_output_exposure_layers_fused"), PanoPanel::OnOutputFilesChanged)
     EVT_CHECKBOX ( XRCID("pano_cb_ldr_output_exposure_remapped"), PanoPanel::OnOutputFilesChanged)
     EVT_CHECKBOX ( XRCID("pano_cb_hdr_output_blended"), PanoPanel::OnOutputFilesChanged)
     EVT_CHECKBOX ( XRCID("pano_cb_hdr_output_stacks"), PanoPanel::OnOutputFilesChanged)
@@ -166,7 +163,6 @@ bool PanoPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, cons
 #endif
 
     /* populate with all available projection types */
-#ifdef HasPANO13
     int nP = panoProjectionFormatCount();
     for(int n=0; n < nP; n++) {
         pano_projection_features proj;
@@ -175,23 +171,6 @@ bool PanoPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, cons
             m_ProjectionChoice->Append(wxGetTranslation(str2));
         }
     }
-#else
-    bool ok = true;
-    int n=0;
-    while(ok) {
-        char name[20];
-        char str[255];
-        sprintf(name,"PanoType%d",n);
-        n++;
-        int len = queryFeatureString(name,str,255);
-        if (len > 0) {
-            wxString str2(str, wxConvLocal);
-            m_ProjectionChoice->Append(wxGetTranslation(str2));
-        } else {
-            ok = false;
-        }
-    }
-#endif
     m_HFOVText = XRCCTRL(*this, "pano_text_hfov" ,wxTextCtrl);
     DEBUG_ASSERT(m_HFOVText);
     m_CalcHFOVButton = XRCCTRL(*this, "pano_button_calc_fov" ,wxButton);
@@ -418,6 +397,8 @@ void PanoPanel::UpdateDisplay(const PanoramaOptions & opt, const bool hasStacks)
             wxCheckBox)->SetValue(opt.outputLDRLayers);
     XRCCTRL(*this, "pano_cb_ldr_output_exposure_blended",
             wxCheckBox)->SetValue(opt.outputLDRExposureBlended);
+    XRCCTRL(*this, "pano_cb_ldr_output_exposure_layers_fused",
+            wxCheckBox)->SetValue(opt.outputLDRExposureLayersFused);
     XRCCTRL(*this, "pano_cb_ldr_output_exposure_layers",
             wxCheckBox)->SetValue(opt.outputLDRExposureLayers);
     XRCCTRL(*this, "pano_cb_ldr_output_exposure_remapped",
@@ -433,6 +414,7 @@ void PanoPanel::UpdateDisplay(const PanoramaOptions & opt, const bool hasStacks)
                               opt.outputLDRLayers || 
                               opt.outputLDRExposureLayers || 
                               opt.outputLDRExposureBlended || 
+                              opt.outputLDRExposureLayersFused || 
                               opt.outputLDRExposureRemapped || 
                               opt.outputHDRBlended || 
                               opt.outputHDRStacks || 
@@ -474,6 +456,7 @@ void PanoPanel::UpdateDisplay(const PanoramaOptions & opt, const bool hasStacks)
 
     bool blenderEnabled = opt.outputLDRBlended || 
                           opt.outputLDRExposureBlended || 
+                          opt.outputLDRExposureLayersFused || 
                           opt.outputLDRExposureLayers || 
                           opt.outputHDRBlended;
 
@@ -481,7 +464,7 @@ void PanoPanel::UpdateDisplay(const PanoramaOptions & opt, const bool hasStacks)
     XRCCTRL(*this, "pano_button_blender_opts", wxButton)->Show(blenderEnabled);
     XRCCTRL(*this, "pano_text_blender", wxStaticText)->Show(blenderEnabled);
 
-    bool fusionEnabled = opt.outputLDRExposureBlended;
+    bool fusionEnabled = (opt.outputLDRExposureBlended || opt.outputLDRExposureLayersFused);
     m_FusionChoice->Show(fusionEnabled);
     XRCCTRL(*this, "pano_button_fusion_opts", wxButton)->Show(fusionEnabled);
     XRCCTRL(*this, "pano_text_fusion", wxStaticText)->Show(fusionEnabled);
@@ -909,7 +892,9 @@ void PanoPanel::DoStitch()
     // copy pto file to temporary file
     wxString currentPTOfn = wxFileName::CreateTempFileName(wxT("huginpto_"));
     if(currentPTOfn.size() == 0) {
-        wxLogError(_("Could not create temporary file"));
+        wxMessageBox(_("Could not create temporary project file"),_("Error"),
+                wxCANCEL | wxICON_ERROR,this);
+        return;
     }
     DEBUG_DEBUG("tmp PTO file: " << (const char *)currentPTOfn.mb_str(wxConvLocal));
     // copy is not enough, need to adjust image path names...
@@ -1033,12 +1018,16 @@ void PanoPanel::OnSendToBatch ( wxCommandEvent & e )
 	wxString projectFile = MainFrame::Get()->getProjectName();
 	if(wxFileName::FileExists(projectFile))
 	{
+#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
+        wxExecute(_T("open -b net.sourceforge.hugin.PTBatcherGUI "+wxQuoteFilename(projectFile)));
+#else
 #ifdef __WINDOWS__
-		wxString huginPath = getExePath(wxGetApp().argv[0])+wxFileName::GetPathSeparator();
+		wxString huginPath = getExePath(wxGetApp().argv[0])+wxFileName::GetPathSeparator(); 
 #else
 		wxString huginPath = _T("");	//we call the batch processor directly without path on linux
 #endif	
 		wxExecute(huginPath+wxT("PTBatcherGUI ")+wxQuoteFilename(projectFile));
+#endif
 
 		/*int i=0;
 		wxString batchFileName = wxStandardPaths::Get().GetUserConfigDir()+wxFileName::GetPathSeparator();
@@ -1198,6 +1187,8 @@ void PanoPanel::OnOutputFilesChanged(wxCommandEvent & e)
         opts.outputLDRExposureLayers = e.IsChecked();
     } else if (id == XRCID("pano_cb_ldr_output_exposure_blended") ) {
         opts.outputLDRExposureBlended = e.IsChecked();
+    } else if (id == XRCID("pano_cb_ldr_output_exposure_layers_fused") ) {
+        opts.outputLDRExposureLayersFused = e.IsChecked();
     } else if (id == XRCID("pano_cb_ldr_output_exposure_remapped") ) {
         opts.outputLDRExposureRemapped = e.IsChecked();
     } else if (id == XRCID("pano_cb_hdr_output_blended") ) {
