@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PreferencesDialog.cpp 3870 2009-05-21 20:46:21Z brunopostle $
+ *  $Id: PreferencesDialog.cpp 4358 2009-09-10 05:06:53Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -29,24 +29,6 @@
 #include "wx/listbook.h"
 #include "panoinc.h"
 
-#ifdef HAVE_PANO12_QUERYFEATURE_H
-#ifndef WIN32
-#include <dlfcn.h>
-#else
-#include <windows.h>
-#endif
-
-extern "C" {
-#ifdef HasPANO13
-#include <pano13/version.h>
-#include <pano13/queryfeature.h>
-#else
-#include <pano12/version.h>
-#include <pano12/queryfeature.h>
-#endif
-}
-#endif
-
 #include "common/wxPlatform.h"
 
 #include "hugin/huginApp.h"
@@ -80,15 +62,19 @@ BEGIN_EVENT_TABLE(PreferencesDialog, wxDialog)
     EVT_BUTTON(XRCID("prefs_editor_select"), PreferencesDialog::OnEditorExe)
     EVT_BUTTON(XRCID("prefs_enblend_select"), PreferencesDialog::OnEnblendExe)
     EVT_BUTTON(XRCID("prefs_enblend_enfuse_select"), PreferencesDialog::OnEnfuseExe)
-    EVT_BUTTON(XRCID("prefs_AutoPanoKolorExe_select"), PreferencesDialog::OnAutopanoKolorExe)
-    EVT_BUTTON(XRCID("prefs_AutoPanoSIFTExe_select"), PreferencesDialog::OnAutopanoSiftExe)
     EVT_BUTTON(XRCID("prefs_load_defaults"), PreferencesDialog::OnDefaults)
     EVT_BUTTON(XRCID("prefs_panotools_details"), PreferencesDialog::OnPTDetails)
     EVT_CHECKBOX(XRCID("prefs_ft_RotationSearch"), PreferencesDialog::OnRotationCheckBox)
-    EVT_CHECKBOX(XRCID("prefs_AutoPanoSIFTExe_custom"), PreferencesDialog::OnCustomAPSIFT)
     EVT_CHECKBOX(XRCID("prefs_enblend_Custom"), PreferencesDialog::OnCustomEnblend)
     EVT_CHECKBOX(XRCID("prefs_enblend_enfuseCustom"), PreferencesDialog::OnCustomEnfuse)
     EVT_CHECKBOX(XRCID("prefs_pt_PTStitcherEXE_custom"), PreferencesDialog::OnCustomPTStitcher)
+    EVT_BUTTON(XRCID("pref_cpdetector_new"), PreferencesDialog::OnCPDetectorAdd)
+    EVT_BUTTON(XRCID("pref_cpdetector_edit"), PreferencesDialog::OnCPDetectorEdit)
+    EVT_BUTTON(XRCID("pref_cpdetector_del"), PreferencesDialog::OnCPDetectorDelete)
+    EVT_BUTTON(XRCID("pref_cpdetector_moveup"), PreferencesDialog::OnCPDetectorMoveUp)
+    EVT_BUTTON(XRCID("pref_cpdetector_movedown"), PreferencesDialog::OnCPDetectorMoveDown)
+    EVT_BUTTON(XRCID("pref_cpdetector_default"), PreferencesDialog::OnCPDetectorDefault)
+    EVT_LISTBOX_DCLICK(XRCID("pref_cpdetector_list"), PreferencesDialog::OnCPDetectorListDblClick)
 //    EVT_CLOSE(RunOptimizerFrame::OnClose)
 END_EVENT_TABLE()
 
@@ -188,6 +174,11 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     lang_choice->Append(_("Ukrainian"), lp);
     lang_choice->SetSelection(0);
 
+    // load autopano settings
+    wxConfigBase * cfg = wxConfigBase::Get();
+    m_CPDetectorList = XRCCTRL(*this, "pref_cpdetector_list", wxListBox);
+    cpdetector_config_edit.Read(cfg);
+
     // Load configuration values from wxConfig
     UpdateDisplayData(0);
 
@@ -199,18 +190,11 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     GetSizer()->SetSizeHints(this);
 //    GetSizer()->Layout();
 
-    wxConfigBase * cfg = wxConfigBase::Get();
-    // reset old options
-    cfg->Write(wxT("/AutoPanoKolor/AutopanoExeCustom"), 0);
 
     // only enable bundled if the build is actually bundled.
 #if defined __WXMSW__ || defined MAC_SELF_CONTAINED_BUNDLE
 
 #else
-    MY_BOOL_VAL("prefs_AutoPanoSIFTExe_custom", HUGIN_APSIFT_EXE_CUSTOM);    
-    XRCCTRL(*this, "prefs_AutoPanoSIFTExe_custom", wxCheckBox)->Hide();
-    cfg->Write(wxT("/AutoPanoSift/AutopanoExeCustom"), HUGIN_APSIFT_EXE_CUSTOM);
-
     MY_BOOL_VAL("prefs_enblend_Custom", HUGIN_ENBLEND_EXE_CUSTOM);
     XRCCTRL(*this, "prefs_enblend_Custom", wxCheckBox)->Hide();
     cfg->Write(wxT("/Enblend/Custom"), HUGIN_ENBLEND_EXE_CUSTOM);
@@ -349,45 +333,6 @@ void PreferencesDialog::OnEnfuseExe(wxCommandEvent & e)
     }
 }
 
-
-void PreferencesDialog::OnAutopanoKolorExe(wxCommandEvent & e)
-{
-    wxFileDialog dlg(this,_("Select Autopano"),
-	             wxT(""), wxT(HUGIN_APKOLOR_EXE),
-#ifdef __WXMSW__
-		     _("Executables (*.exe)|*.exe"),
-#else
-		     wxT(""),
-#endif
-                    wxOPEN, wxDefaultPosition);
-    if (dlg.ShowModal() == wxID_OK) {
-	XRCCTRL(*this, "prefs_AutoPanoKolorExe", wxTextCtrl)->SetValue(
-		dlg.GetPath());
-    }
-}
-
-void PreferencesDialog::OnAutopanoSiftExe(wxCommandEvent & e)
-{
-    wxFileDialog dlg(this,_("Select Autopano-SIFT"),
-	             wxT(""), wxT(HUGIN_APSIFT_EXE),
-#ifdef __WXMSW__
-		     _("Executables (*.exe,*.vbs,*.cmd)|*.exe;*.vbs;*.cmd"),
-#else
-		     wxT(""),
-#endif
-                    wxOPEN, wxDefaultPosition);
-    if (dlg.ShowModal() == wxID_OK) {
-	XRCCTRL(*this, "prefs_AutoPanoSIFTExe", wxTextCtrl)->SetValue(
-		dlg.GetPath());
-    }
-}
-
-void PreferencesDialog::OnCustomAPSIFT(wxCommandEvent & e)
-{
-    XRCCTRL(*this, "prefs_AutoPanoSIFTExe", wxTextCtrl)->Enable(e.IsChecked());
-    XRCCTRL(*this, "prefs_AutoPanoSIFTExe_select", wxButton)->Enable(e.IsChecked());
-}
-
 void PreferencesDialog::OnCustomEnblend(wxCommandEvent & e)
 {
     XRCCTRL(*this, "prefs_enblend_EnblendExe", wxTextCtrl)->Enable(e.IsChecked());
@@ -441,175 +386,7 @@ typedef int (*PROC_QFSTRING)	(const char *, char *, const int);
 
 bool PreferencesDialog::GetPanoVersion()
 {
-
-#ifdef HAVE_PANO12_QUERYFEATURE_H
-#ifdef __WXMSW__
-	HINSTANCE		hDll		= NULL;
-#elif (!defined __WXMAC__)
-	void *hDll = NULL;
-#endif
-	PROC_QF			pfQF		= NULL;
-	PROC_QFNUM		pfQFNum		= NULL;
-	PROC_QFINT		pfQFInt		= NULL;
-	PROC_QFDOUBLE	pfQFDouble	= NULL;
-	PROC_QFSTRING	pfQFString	= NULL;
-
-	int				iResult;
-	double			dResult;
-	char			sResult[256];
-	char			str1[1000];
-	char			str2[10000];
-	bool			bSuccess = true;
-
-#ifdef __WXMSW__
-	hDll = LoadLibrary(_T("pano13.dll"));
-	if(!hDll)
-	{
-		//MessageBox((HWND)NULL, _("Could not load dll"), _("panoinfo"), MB_ICONEXCLAMATION);
-		bSuccess = false;
-		goto cleanup;
-	}
-
-	pfQF		= (PROC_QF) GetProcAddress( hDll, "queryFeatures" );
-	pfQFNum		= (PROC_QFNUM) GetProcAddress( hDll, "queryFeatureCount" );
-	pfQFInt     = (PROC_QFINT) GetProcAddress( hDll, "queryFeatureInt" );
-	pfQFDouble  = (PROC_QFDOUBLE) GetProcAddress( hDll, "queryFeatureDouble" );
-	pfQFString  = (PROC_QFSTRING) GetProcAddress( hDll, "queryFeatureString" );
-#elif (defined __WXMAC__)
-//HuginOSX has libpano12 statically linked; hard code the query functions instead
-	pfQF		= (PROC_QF) queryFeatures;
-	pfQFNum		= (PROC_QFNUM) queryFeatureCount;
-	pfQFInt     = (PROC_QFINT) queryFeatureInt;
-	pfQFDouble  = (PROC_QFDOUBLE) queryFeatureDouble;
-	pfQFString  = (PROC_QFSTRING) queryFeatureString;
-#else
-	hDll = dlopen("libpano13.so.0", RTLD_NOW);
-	if(!hDll)
-	{
-		hDll = dlopen("libpano13.so", RTLD_NOW);
-		if(!hDll)
-		{
-		  printf("Could not load pano13");
-		  bSuccess = false;
-		  goto cleanup;
-		}
-	}
-
-	pfQF		= (PROC_QF) dlsym( hDll, "queryFeatures" );
-	pfQFNum		= (PROC_QFNUM) dlsym( hDll, "queryFeatureCount" );
-	pfQFInt     = (PROC_QFINT) dlsym( hDll, "queryFeatureInt" );
-	pfQFDouble  = (PROC_QFDOUBLE) dlsym( hDll, "queryFeatureDouble" );
-	pfQFString  = (PROC_QFSTRING) dlsym( hDll, "queryFeatureString" );
-#endif
-	str2[0] = '\0';
-	if(!pfQF)
-	{
-		strcat(str2 ,"Error: The 'queryFeatures' function not present\n");
-	}
-	if(!pfQFNum)
-	{
-		strcat(str2 ,"Error: The 'queryFeatureCount' function not present\n");
-	}
-	if(!pfQFString)
-	{
-		strcat(str2 ,"Error: The 'queryFeatureString' function not present\n");
-	}
-	if(!pfQFInt)
-	{
-		strcat(str2 ,"Error: The 'queryFeatureInt' function not present\n");
-	}
-	if(!pfQFDouble)
-	{
-		strcat(str2 ,"Error: The 'queryFeatureDouble' function not present\n");
-	}
-
-
-	if(pfQFString)
-	{
-		if((pfQFString) (PTVERSION_NAME_FILEVERSION, sResult, sizeof(sResult)/sizeof(sResult[0]) ))
-		{
-			m_PTVersion = wxString(sResult, wxConvLocal);
-		}
-
-		if((pfQFString) (PTVERSION_NAME_COMMENT, sResult, sizeof(sResult)/sizeof(sResult[0]) ))
-		{
-			sprintf(str1, "Comment:\t%s\n", sResult );
-			strcat(str2 ,str1);
-		}
-
-		if((pfQFString) (PTVERSION_NAME_LEGALCOPYRIGHT, sResult, sizeof(sResult)/sizeof(sResult[0]) ))
-		{
-			sprintf(str1, "Copyright:\t%s\n\n", sResult );
-			strcat(str2 ,str1);
-		}
-
-	}
-
-	if(pfQFInt)
-	{
-		if((pfQFInt) ("CPErrorIsDistSphere", &iResult ))
-		{
-			sprintf(str1, "Optimizer Error:\t%s\n", iResult? "dist sphere" : "dist rect" );
-			strcat(str2 ,str1);
-		}
-	}
-
-	if(pfQFDouble)
-	{
-		if((pfQFDouble) ("MaxFFOV", &dResult ))
-		{
-			sprintf(str1, "Max FoV:\t\t%f\n\n", dResult );
-			strcat(str2 ,str1);
-		}
-
-	}
-
-	if(pfQFNum && pfQF && pfQFString)
-	{
-		int i,bufsize,numfeatures;
-		char *name;
-		char *value;
-		Tp12FeatureType type;
-
-		strcat(str2 ,"Feature List:\n\n");
-
-		numfeatures = pfQFNum();
-		for(i=0; i < numfeatures;i++)
-		{
-			pfQF(i, &name, &type);
-			bufsize = pfQFString(name, NULL, 0)+1;
-			value = (char*)malloc(bufsize);
-			pfQFString(name, value, bufsize);
-
-			sprintf(str1, "   %s: %s\n", name, value);
-			strcat(str2 ,str1);
-
-			free(value);
-		}
-	}
-	// use wxConvLocal to deal with the copyright symbols used by panotools
-	m_PTDetails = wxString(str2, wxConvLocal);
-
-#ifndef __WXMAC__
-cleanup:
-#endif
-
-  if (bSuccess)
-  {
-#ifdef __WXMSW__
-	FreeLibrary(hDll);
-#elif defined __WXMAC__
-//nothing to do
-#else
-	dlclose(hDll);
-#endif
-	return true;
-  } else {
-	return false;
-  }
-#else // HAVE_PANO12_QUERYFEATURE_H
   return false;
-#endif
 }
 
 void PreferencesDialog::UpdateDisplayData(int panel)
@@ -684,6 +461,7 @@ void PreferencesDialog::UpdateDisplayData(int panel)
                    wxT(HUGIN_STITCHER_EDITOR)));
         MY_STR_VAL("prefs_ass_editor_args", cfg->Read(wxT("/Stitcher/EditorArgs"),
                    wxT(HUGIN_STITCHER_EDITOR_ARGS)));
+        MY_CHOICE_VAL("prefs_ass_preview", cfg->Read(wxT("/Assistant/PreviewWindow"), 1l));
     }
        // Fine tune settings
 
@@ -728,35 +506,21 @@ void PreferencesDialog::UpdateDisplayData(int panel)
     /// MISC
 
     /////
-    /// AUTOPANO
+    /// CP Detector programs
 
     if (panel==0 || panel == 4){
-        // active autopano
-        MY_CHOICE_VAL("prefs_AutoPanoType", cfg->Read(wxT("/AutoPano/Type"), HUGIN_AP_TYPE));
-
-        // Autopano-SIFT
-        MY_STR_VAL("prefs_AutoPanoSIFTExe", cfg->Read(wxT("/AutoPanoSift/AutopanoExe"),
-                                                  wxT(HUGIN_APSIFT_EXE)));
-
-        bool customAutopanoExe = HUGIN_APSIFT_EXE_CUSTOM;
-        //bool customAutopanoExe =  //TODO: compatibility mode; to be fixed
-        //    (wxT(HUGIN_APSIFT_EXE) != cfg->Read(wxT("/AutoPanoSift/AutopanoExe"), wxT(HUGIN_APSIFT_EXE)));
-        cfg->Read(wxT("/AutoPanoSift/AutopanoExeCustom"), &customAutopanoExe);
-        MY_BOOL_VAL("prefs_AutoPanoSIFTExe_custom", customAutopanoExe);
-        XRCCTRL(*this, "prefs_AutoPanoSIFTExe", wxTextCtrl)->Enable(customAutopanoExe);
-        XRCCTRL(*this, "prefs_AutoPanoSIFTExe_select", wxButton)->Enable(customAutopanoExe);
-        MY_STR_VAL("prefs_AutoPanoSIFTArgs", cfg->Read(wxT("/AutoPanoSift/Args"),
-                                                   wxT(HUGIN_APSIFT_ARGS)));
-
-        // Autopano
-        MY_STR_VAL("prefs_AutoPanoKolorExe", cfg->Read(wxT("/AutoPanoKolor/AutopanoExe"),
-                                                   wxT(HUGIN_APKOLOR_EXE)));
-        MY_STR_VAL("prefs_AutoPanoKolorArgs", cfg->Read(wxT("/AutoPanoKolor/Args"),
-                                                   wxT(HUGIN_APKOLOR_ARGS)));
-
+        cpdetector_config_edit.FillControl(m_CPDetectorList,true,true);
     }
 
     if (panel==0 || panel == 5){
+        /////
+        /// NONA
+        MY_CHOICE_VAL("prefs_nona_interpolator", cfg->Read(wxT("/Nona/Interpolator"), HUGIN_NONA_INTERPOLATOR));
+        t = cfg->Read(wxT("/Nona/CroppedImages"), HUGIN_NONA_CROPPEDIMAGES) == 1;
+        MY_BOOL_VAL("prefs_nona_createCroppedImages", t);
+        t = cfg->Read(wxT("/Nona/UseGPU"), HUGIN_NONA_USEGPU) == 1;
+        MY_BOOL_VAL("prefs_nona_useGpu", t);
+
         /////
         /// ENBLEND
         MY_STR_VAL("prefs_enblend_EnblendExe", cfg->Read(wxT("/Enblend/Exe"),
@@ -853,6 +617,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
             cfg->Write(wxT("/Stitcher/RunEditor"), HUGIN_STITCHER_RUN_EDITOR);
             cfg->Write(wxT("/Stitcher/Editor"), wxT(HUGIN_STITCHER_EDITOR));
             cfg->Write(wxT("/Stitcher/EditorArgs"), wxT(HUGIN_STITCHER_EDITOR_ARGS));
+            cfg->Write(wxT("/Assistant/PreviewWindow"), 1l);
         }
         if (noteb->GetSelection() == 2) {
             // hdr
@@ -874,14 +639,8 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
         if (noteb->GetSelection() == 3) {
             /////
             /// AUTOPANO
-            cfg->Write(wxT("/AutoPano/Type"), HUGIN_AP_TYPE);
-
-            cfg->Write(wxT("/AutoPanoSift/AutopanoExe"), wxT(HUGIN_APSIFT_EXE));
-            cfg->Write(wxT("/AutoPanoSift/AutopanoExeCustom"), HUGIN_APSIFT_EXE_CUSTOM);
-            cfg->Write(wxT("/AutoPanoSift/Args"), wxT(HUGIN_APSIFT_ARGS));
-
-            cfg->Write(wxT("/AutoPanoKolor/AutopanoExe"), wxT(HUGIN_APKOLOR_EXE));
-            cfg->Write(wxT("/AutoPanoKolor/Args"), wxT(HUGIN_APKOLOR_ARGS));
+            cpdetector_config_edit.ResetToDefault();
+            cpdetector_config_edit.Write(cfg);
         }
         if (noteb->GetSelection() == 4) {
             /// ENBLEND
@@ -927,6 +686,7 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Assistant/autoAlign"),MY_G_BOOL_VAL("prefs_ass_autoAlign"));
     cfg->Write(wxT("/Assistant/nControlPoints"), MY_G_SPIN_VAL("prefs_ass_nControlPoints"));
     cfg->Write(wxT("/Assistant/panoDownsizeFactor"), MY_G_SPIN_VAL("prefs_ass_panoDownsizeFactor") / 100.0);
+    cfg->Write(wxT("/Assistant/PreviewWindow"), MY_G_CHOICE_VAL("prefs_ass_preview"));
     // editor
     cfg->Write(wxT("/Stitcher/RunEditor"), MY_G_BOOL_VAL("prefs_ass_run_editor"));
     cfg->Write(wxT("/Stitcher/Editor"), MY_G_STR_VAL("prefs_ass_editor"));
@@ -983,16 +743,14 @@ void PreferencesDialog::UpdateConfigData()
     
     /////
     /// AUTOPANO
-    cfg->Write(wxT("/AutoPano/Type"),MY_G_CHOICE_VAL("prefs_AutoPanoType"));
-    
-    cfg->Write(wxT("/AutoPanoSift/AutopanoExeCustom"), MY_G_BOOL_VAL("prefs_AutoPanoSIFTExe_custom"));
-    cfg->Write(wxT("/AutoPanoSift/AutopanoExe"), MY_G_STR_VAL("prefs_AutoPanoSIFTExe"));
-    cfg->Write(wxT("/AutoPanoSift/Args"),MY_G_STR_VAL("prefs_AutoPanoSIFTArgs"));
-    
-    cfg->Write(wxT("/AutoPanoKolor/AutopanoExe"),MY_G_STR_VAL("prefs_AutoPanoKolorExe"));
-    cfg->Write(wxT("/AutoPanoKolor/Args"),MY_G_STR_VAL("prefs_AutoPanoKolorArgs"));
-    
-    
+    cpdetector_config_edit.Write(cfg);
+
+    /////
+    /// STITCHING
+    cfg->Write(wxT("/Nona/Interpolator"), MY_G_CHOICE_VAL("prefs_nona_interpolator"));
+    cfg->Write(wxT("/Nona/CroppedImages"), MY_G_BOOL_VAL("prefs_nona_createCroppedImages"));
+    cfg->Write(wxT("/Nona/UseGPU"), MY_G_BOOL_VAL("prefs_nona_useGpu"));
+
     /////
     /// ENBLEND
     cfg->Write(wxT("/Enblend/Custom"), MY_G_BOOL_VAL("prefs_enblend_Custom"));
@@ -1014,3 +772,96 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Flush();
     UpdateDisplayData(0);
 }
+
+void PreferencesDialog::OnCPDetectorAdd(wxCommandEvent & e)
+{
+    CPDetectorDialog cpdetector_dlg(this);
+    if(cpdetector_dlg.ShowModal()==wxOK)
+    {
+        cpdetector_config_edit.settings.Add(new CPDetectorSetting);
+        cpdetector_dlg.UpdateSettings(&cpdetector_config_edit,cpdetector_config_edit.GetCount()-1);
+        cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+        m_CPDetectorList->SetSelection(cpdetector_config_edit.GetCount()-1);
+    };
+};
+
+void PreferencesDialog::OnCPDetectorEdit(wxCommandEvent & e)
+{
+    CPDetectorDialog autopano_dlg(this);
+    int selection=m_CPDetectorList->GetSelection();
+    if (selection == wxNOT_FOUND) 
+    {
+        wxMessageBox(_("Please select an entry first"),_("Select Entry"),wxOK |
+                wxICON_EXCLAMATION,this);
+    } else 
+    {
+        autopano_dlg.UpdateFields(&cpdetector_config_edit, selection);
+        if(autopano_dlg.ShowModal()==wxOK)
+        {
+            autopano_dlg.UpdateSettings(&cpdetector_config_edit, selection);
+            cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+            m_CPDetectorList->SetSelection(selection);
+        };
+    }
+};
+
+void PreferencesDialog::OnCPDetectorDelete(wxCommandEvent & e)
+{
+    unsigned int selection=m_CPDetectorList->GetSelection();
+    if(m_CPDetectorList->GetCount()==1)
+    {
+        wxMessageBox(_("You can't delete the last setting.\nAt least one setting is required."),_("Warning"),wxOK | wxICON_EXCLAMATION,this);
+    }
+    else
+    {
+        if(wxMessageBox(wxString::Format(_("Do you really want to remove autopano setting \"%s\"?"),cpdetector_config_edit.settings[selection].GetCPDetectorDesc().c_str())
+            ,_("Delete autopano setting"),wxYES_NO | wxICON_QUESTION,this)==wxYES)
+        {
+            if(cpdetector_config_edit.GetDefaultGenerator()==selection)
+                cpdetector_config_edit.SetDefaultGenerator(0);
+            cpdetector_config_edit.settings.RemoveAt(selection);
+            cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+            if(selection>=m_CPDetectorList->GetCount())
+                selection=m_CPDetectorList->GetCount()-1;
+            m_CPDetectorList->SetSelection(selection);
+        };
+    };
+};
+
+void PreferencesDialog::OnCPDetectorMoveUp(wxCommandEvent & e)
+{
+    unsigned int selection=m_CPDetectorList->GetSelection();
+    if(selection>0)
+    {
+        cpdetector_config_edit.Swap(selection-1);
+        cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+        m_CPDetectorList->SetSelection(selection-1);
+    };
+};
+
+void PreferencesDialog::OnCPDetectorMoveDown(wxCommandEvent & e)
+{
+    unsigned int selection=m_CPDetectorList->GetSelection();
+    if(selection<m_CPDetectorList->GetCount()-1)
+    {
+        cpdetector_config_edit.Swap(selection);
+        cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+        m_CPDetectorList->SetSelection(selection+1);
+    };
+};
+
+void PreferencesDialog::OnCPDetectorDefault(wxCommandEvent & e)
+{
+    unsigned int selection=m_CPDetectorList->GetSelection();
+    if(selection!=cpdetector_config_edit.GetDefaultGenerator())
+    {
+        cpdetector_config_edit.SetDefaultGenerator(selection);
+        cpdetector_config_edit.FillControl(m_CPDetectorList,false,true);
+        m_CPDetectorList->SetSelection(selection);
+    };
+};
+
+void PreferencesDialog::OnCPDetectorListDblClick(wxCommandEvent &e)
+{
+    OnCPDetectorEdit(e);
+};
