@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: huginApp.cpp 3730 2009-03-14 07:44:44Z tmodes $
+ *  $Id: huginApp.cpp 4362 2009-09-10 16:16:26Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -130,6 +130,7 @@ bool huginApp::OnInit()
     wxFileName::SplitPath( huginExeDir, &huginRoot, NULL, NULL );
 
     m_xrcPrefix = huginRoot + wxT("/share/hugin/xrc/");
+	m_DataDir = huginRoot + wxT("/share/hugin/data/");
     m_utilsBinDir = huginRoot + wxT("/bin/");
 
     // locale setup
@@ -144,6 +145,7 @@ bool huginApp::OnInit()
             return false;
         }
         m_xrcPrefix = thePath + wxT("/");
+        m_DataDir = thePath + wxT("/");
     }
 
     {
@@ -159,6 +161,7 @@ bool huginApp::OnInit()
 #else
     // add the locale directory specified during configure
     m_xrcPrefix = wxT(INSTALL_XRC_DIR);
+    m_DataDir = wxT(INSTALL_DATA_DIR);
     locale.AddCatalogLookupPathPrefix(wxT(INSTALL_LOCALE_DIR));
 #endif
 
@@ -236,6 +239,7 @@ bool huginApp::OnInit()
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("help.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("keyboard_help.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("pref_dialog.xrc"));
+    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("cpdetector_dialog.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("reset_dialog.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("vig_corr_dlg.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("optimize_photo_panel.xrc"));
@@ -315,6 +319,9 @@ bool huginApp::OnInit()
     opts.blendMode = PanoramaOptions::ENBLEND_BLEND;
     opts.enblendOptions = config->Read(wxT("Enblend/Args"),wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
     opts.enfuseOptions = config->Read(wxT("Enfuse/Args"),wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
+	opts.interpolator = (vigra_ext::Interpolator)config->Read(wxT("Nona/Interpolator"),HUGIN_NONA_INTERPOLATOR);
+	opts.remapUsingGPU = (bool)config->Read(wxT("Nona/useGPU"),HUGIN_NONA_USEGPU);
+	opts.tiff_saveROI = (bool)config->Read(wxT("Nona/CroppedImages"),HUGIN_NONA_CROPPEDIMAGES);
     pano.setOptions(opts);
 
     if (argc > 1) {
