@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: wxPanoCommand.cpp 3944 2009-06-17 05:34:34Z tmodes $
+ *  $Id: wxPanoCommand.cpp 4439 2009-09-17 16:55:13Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -319,6 +319,9 @@ void wxLoadPTProjectCmd::execute()
             opts.enblendOptions = wxConfigBase::Get()->Read(wxT("/Enblend/Args"), wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
             opts.enfuseOptions = wxConfigBase::Get()->Read(wxT("/Enfuse/Args"), wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
         }
+        // Set the nona gpu flag base on what is in preferences as it is not
+        // stored in the file.
+        opts.remapUsingGPU = wxConfigBase::Get()->Read(wxT("/Nona/UseGPU"),HUGIN_NONA_USEGPU) == 1;
         pano.setOptions(opts);
 
         unsigned int nImg = pano.getNrOfImages();
@@ -409,6 +412,36 @@ void wxLoadPTProjectCmd::execute()
         DEBUG_ERROR("could not load panotools script");
     }
     in.close();
+
+    // Verify control points are valid
+    // loop through entire list of points, confirming they are inside the
+    // bounding box of their images
+    const PT::CPVector & oldCPs = pano.getCtrlPoints();
+    PT::CPVector goodCPs;
+    int bad_cp_count = 0;
+    for (PT::CPVector::const_iterator it = oldCPs.begin(); 
+            it != oldCPs.end(); ++it)
+    {
+        PT::ControlPoint point = *it;
+        SrcPanoImage img1 = pano.getSrcImage(point.image1Nr);
+        SrcPanoImage img2 = pano.getSrcImage(point.image2Nr);
+        if (point.x1 > img1.getSize().x || point.y1 > img1.getSize().y ||
+           point.x2 > img2.getSize().x || point.y2 > img2.getSize().y) 
+        {
+            bad_cp_count++;
+        } else 
+        {
+            goodCPs.push_back(point);
+        }
+    }
+
+    if (bad_cp_count > 0) 
+    {
+        wxString errMsg = wxString::Format(_("%d invalid control point(s) found.\n\nPress OK to remove."), bad_cp_count);
+        wxMessageBox(errMsg, _("Error Detected"), wxICON_ERROR);
+        pano.setCtrlPoints(goodCPs);
+    }
+
     // Update control point error values
     HuginBase::PTools::calcCtrlPointErrors(pano);
     pano.changeFinished();
