@@ -11,4 +11,6 @@ wget --input-file=pages.txt \
     --exclude-directories=wiki/skins \
     --ignore-tags=link
 
+rm robots.txt
+rm index.php*
 
