@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: hugin_stitch_project.cpp 3792 2009-04-17 05:49:49Z tmodes $
+ *  $Id: hugin_stitch_project.cpp 4315 2009-09-03 01:00:39Z yuv $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -134,7 +134,7 @@ RunStitchFrame::RunStitchFrame(wxWindow * parent, const wxString& title, const w
 
 void RunStitchFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
 {
-    wxMessageBox( wxString::Format(_("HuginStitchProject. Application to stitch hugin project files.\n Version: %s"), wxT(PACKAGE_VERSION)),
+    wxMessageBox( wxString::Format(_("HuginStitchProject. Application to stitch hugin project files.\n Version: %s"), wxT(DISPLAY_VERSION)),
                   wxT("About hugin_stitch_project"),
                   wxOK | wxICON_INFORMATION );
 }
@@ -244,7 +244,12 @@ bool stitchApp::OnInit()
     // Required to access the preferences of hugin
     SetAppName(wxT("hugin"));
 
+#if defined __WXMSW__
+    int localeID = wxConfigBase::Get()->Read(wxT("language"), (long) wxLANGUAGE_DEFAULT);
+    m_locale.Init(localeID);
+#else
     m_locale.Init(wxLANGUAGE_DEFAULT);
+#endif
 
     // setup the environment for the different operating systems
 #if defined __WXMSW__
