@@ -61,6 +61,7 @@ vector<UIntSet> getHDRStacks(const PanoramaData & pano, UIntSet allImgs)
 
         // find all images that have a suitable overlap.
         SrcPanoImage simg = pano.getSrcImage(srcImg);
+        // FIXME this should be a user preference
         double maxShift = simg.getHFOV() / 10.0;
         double minShift = 360.0 - maxShift;
         for (UIntSet::iterator it = allImgs.begin(); it !=  allImgs.end(); ) {
@@ -102,7 +103,8 @@ vector<UIntSet> getExposureLayers(const PanoramaData & pano, UIntSet allImgs)
 
         // find all images that have a suitable overlap.
         SrcPanoImage simg = pano.getSrcImage(srcImg);
-        double maxEVDiff = 0.2;
+        // FIXME this should be a user preference
+        double maxEVDiff = 0.5;
         for (UIntSet::iterator it = allImgs.begin(); it !=  allImgs.end(); ) {
             unsigned srcImg2 = *it;
             it++;
@@ -234,6 +236,12 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                     o << "-z PACKBITS ";
                 }
                 o << endl;
+                o << "NONA_OPTS=";
+                if (opts.remapUsingGPU)
+                {
+                    o << "-g ";
+                }
+                o << endl;
             }
             break;
         case PanoramaOptions::PTMENDER:
@@ -342,6 +350,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
 */
     std::string sLDR_BLENDED = output + ldrExt;
     std::string sLDR_STACKED_BLENDED = output + "_fused" + ldrExt;
+    std::string sLDR_EXPOSURE_LAYERS_FUSED = output + "_blended_fused" + ldrExt;
     std::string sHDR_BLENDED = output + "_hdr" + hdrExt;
 
     o << "# the output panorama" << endl
@@ -363,6 +372,9 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
     << "LDR_STACKED_BLENDED=" << escapeStringMake(sLDR_STACKED_BLENDED) << endl
     << "LDR_STACKED_BLENDED_SHELL=" << quoteStringShell(sLDR_STACKED_BLENDED) << endl
 
+    << "LDR_EXPOSURE_LAYERS_FUSED=" << escapeStringMake(sLDR_EXPOSURE_LAYERS_FUSED) << endl
+    << "LDR_EXPOSURE_LAYERS_FUSED_SHELL=" << quoteStringShell(sLDR_EXPOSURE_LAYERS_FUSED) << endl
+
     << "HDR_BLENDED=" << escapeStringMake(sHDR_BLENDED) << endl
     << "HDR_BLENDED_SHELL=" << quoteStringShell(sHDR_BLENDED) << endl
     << endl
@@ -686,6 +698,18 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
             }
         }
 
+        if (opts.outputLDRExposureLayersFused) {
+            targets += " $(LDR_EXPOSURE_LAYERS_FUSED) ";
+            outputFiles.push_back(sLDR_EXPOSURE_LAYERS_FUSED);
+            o << "DO_LDR_EXPOSURE_LAYERS_FUSED = 1" << endl;
+            outputFiles.insert(outputFiles.end(),similarExposureImages.begin(), similarExposureImages.end());
+            if (! opts.outputLDRExposureRemapped && ! opts.outputLDRExposureLayers) {
+                outputFiles.insert(outputFiles.end(), similarExposureRemappedImages.begin(), similarExposureRemappedImages.end());
+                cleanTargets += "$(LDR_EXPOSURE_LAYERS_REMAPPED_SHELL) ";
+                cleanTargets += "$(LDR_EXPOSURE_LAYERS_SHELL) ";
+            }
+        }
+
         if (opts.outputHDRLayers) {
             targets += "$(HDR_LAYERS) ";
             outputFiles.insert(outputFiles.end(),remappedHDRImages.begin(), remappedHDRImages.end());
@@ -787,7 +811,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                         string destImg = escapeStringMake(remappedImages[i]);
                         string srcImg = escapeStringMake(pano.getImage(*it).getFilename());
                         o << destImg << ": " << srcImg << " $(PROJECT_FILE)" << endl
-                        << "\t$(NONA) $(NONA_LDR_REMAPPED_COMP) -r ldr -m " << ldrRemappedMode << " -o $(LDR_REMAPPED_PREFIX_SHELL) -i " << *it << " $(PROJECT_FILE_SHELL)" << endl << endl;
+                        << "\t$(NONA) $(NONA_OPTS) $(NONA_LDR_REMAPPED_COMP) -r ldr -m " << ldrRemappedMode << " -o $(LDR_REMAPPED_PREFIX_SHELL) -i " << *it << " $(PROJECT_FILE_SHELL)" << endl << endl;
                         i++;
                     }
 
@@ -799,7 +823,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                         string destImg = escapeStringMake(remappedHDRImages[i]);
                         string srcImg = escapeStringMake(pano.getImage(*it).getFilename());
                         o << destImg << ": " << srcImg << " $(PROJECT_FILE)" << endl
-                        << "\t$(NONA) -r hdr -m " << hdrRemappedMode << " -o $(HDR_STACK_REMAPPED_PREFIX_SHELL) -i " << *it << " $(PROJECT_FILE_SHELL)" << endl << endl;
+                        << "\t$(NONA) $(NONA_OPTS) -r hdr -m " << hdrRemappedMode << " -o $(HDR_STACK_REMAPPED_PREFIX_SHELL) -i " << *it << " $(PROJECT_FILE_SHELL)" << endl << endl;
                         i++;
                     }
 
@@ -819,7 +843,7 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                               << " $(PROJECT_FILE)" << endl << endl;
                             */
                             o << destImg << ": " << srcImg << " $(PROJECT_FILE)" << endl
-                              << "\t$(NONA) $(NONA_LDR_REMAPPED_COMP) -r ldr -e " << pano.getSrcImage(*it).getExposureValue()
+                              << "\t$(NONA) $(NONA_OPTS) $(NONA_LDR_REMAPPED_COMP) -r ldr -e " << pano.getSrcImage(*it).getExposureValue()
                               << " -m " << ldrRemappedMode << " -o $(LDR_EXPOSURE_REMAPPED_PREFIX_SHELL) -i " << *it
                               << " $(PROJECT_FILE_SHELL)" << endl << endl;
                             j++;
@@ -873,10 +897,29 @@ void PanoramaMakefileExport::createMakefile(const PanoramaData& pano,
                   << "\t$(ENBLEND) $(ENBLEND_LDR_COMP) $(ENBLEND_OPTS) -o $(LDR_STACKED_BLENDED_SHELL) $(LDR_STACKS_SHELL) " << endl
                   << "\t- $(EXIFTOOL) -overwrite_original_in_place -TagsFromFile $(INPUT_IMAGE_1_SHELL) $(EXIFTOOL_COPY_ARGS) $(LDR_STACKED_BLENDED_SHELL)" << endl << endl;
 
+                // rules for fusing blended layers
+                o << "$(LDR_EXPOSURE_LAYERS_FUSED) : $(LDR_EXPOSURE_LAYERS)" << endl
+                  << "\t$(ENFUSE) $(ENBLEND_LDR_COMP) $(ENFUSE_OPTS) -o $(LDR_EXPOSURE_LAYERS_FUSED_SHELL) $(LDR_EXPOSURE_LAYERS_SHELL) " << endl
+                  << "\t- $(EXIFTOOL) -overwrite_original_in_place -TagsFromFile $(INPUT_IMAGE_1_SHELL) $(EXIFTOOL_COPY_ARGS) $(LDR_EXPOSURE_LAYERS_FUSED_SHELL)" << endl << endl;
+
                 // rules for hdr blending
                 o << "$(HDR_BLENDED) : $(HDR_STACKS)" << endl;
                 o << "\t$(ENBLEND) $(ENBLEND_HDR_COMP) $(ENBLEND_OPTS) -o $(HDR_BLENDED_SHELL) $(HDR_STACKS_SHELL) " << endl << endl;
 
+                // rules for multilayer output
+
+                o << "$(LDR_REMAPPED_PREFIX)_multilayer.tif : $(LDR_LAYERS)" << endl;
+                o << "\ttiffcp $(LDR_LAYERS_SHELL) $(LDR_REMAPPED_PREFIX_SHELL)_multilayer.tif" << endl << endl;
+
+                o << "$(LDR_REMAPPED_PREFIX)_fused_multilayer.tif : $(LDR_STACKS) $(LDR_EXPOSURE_LAYERS)" << endl;
+                o << "\ttiffcp $(LDR_STACKS_SHELL) $(LDR_EXPOSURE_LAYERS_SHELL) $(LDR_REMAPPED_PREFIX_SHELL)_fused_multilayer.tif" << endl << endl;
+
+                o << "$(LDR_REMAPPED_PREFIX)_multilayer.psd : $(LDR_LAYERS)" << endl;
+                o << "\tPTtiff2psd -o $(LDR_REMAPPED_PREFIX_SHELL)_multilayer.psd $(LDR_LAYERS_SHELL)" << endl << endl;
+
+                o << "$(LDR_REMAPPED_PREFIX)_fused_multilayer.psd : $(LDR_STACKS) $(LDR_EXPOSURE_LAYERS)" << endl;
+                o << "\tPTtiff2psd -o $(LDR_REMAPPED_PREFIX_SHELL)_fused_multilayer.psd $(LDR_STACKS_SHELL) $(LDR_EXPOSURE_LAYERS_SHELL)" << endl << endl;
+
                 break;
             case PanoramaOptions::NO_BLEND:
                 o << "$(LDR_BLENDED) : $(LDR_LAYERS)" << endl
