@@ -6,7 +6,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: hugin_math.h 3479 2008-10-08 09:35:22Z dangelo $
+ *  $Id: hugin_math.h 4429 2009-09-15 15:56:00Z yuv $
  *
  *  This is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -44,11 +44,21 @@
 #define RAD_TO_DEG( x )		( (x) * 360.0 / ( 2.0 * PI ) )
 
 
-#ifdef _MSC_VER
+#ifndef HAVE_LOG2
+
+// #ifdef _MSC_VER
 inline double log2(double x)
 {
     return log(x)/log(2.0);
 }
+
+// #else
+// FreeBSD downstream patch used to implement it as define
+// check if the 
+// #define log2(x)	(log(x) / log(2))
+
+// #endif
+
 #endif
 
 
