@@ -5,7 +5,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: Panorama.cpp 3202 2008-07-18 02:48:57Z gpatters1 $
+ *  $Id: Panorama.cpp 4268 2009-08-24 03:26:11Z gpatters1 $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -800,6 +800,7 @@ void Panorama::printPanoramaScript(std::ostream & o,
     o << "#hugin_outputLDRExposureRemapped " << (output.outputLDRExposureRemapped ? "true" : "false") << endl;
     o << "#hugin_outputLDRExposureLayers " << (output.outputLDRExposureLayers ? "true" : "false") << endl;
     o << "#hugin_outputLDRExposureBlended " << (output.outputLDRExposureBlended ? "true" : "false") << endl;
+    o << "#hugin_outputLDRExposureLayersFused " << (output.outputLDRExposureLayersFused ? "true" : "false") << endl;
     o << "#hugin_outputHDRBlended " << (output.outputHDRBlended ? "true" : "false") << endl;
     o << "#hugin_outputHDRLayers " << (output.outputHDRLayers ? "true" : "false") << endl;
     o << "#hugin_outputHDRStacks " << (output.outputHDRStacks ? "true" : "false") << endl;    
@@ -1665,7 +1666,8 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
     DEBUG_TRACE("");
 #ifdef __unix__
     // set numeric locale to C, for correct number output
-    char * old_locale = setlocale(LC_NUMERIC,NULL);
+    char * p = setlocale(LC_NUMERIC,NULL);
+    char * old_locale = strdup(p);
     setlocale(LC_NUMERIC,"C");
 #endif
     PTParseState state;
@@ -1701,6 +1703,7 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
     options.outputLDRBlended = true;
     options.outputLDRLayers = false;
     options.outputLDRExposureLayers = false;
+    options.outputLDRExposureLayersFused = false;
     options.outputHDRBlended = false;
     options.outputHDRLayers = false;
     options.outputHDRStacks = false;
@@ -2114,6 +2117,8 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
                         options.outputLDRExposureLayers = (value == "true");
                     } else if (var == "#hugin_outputLDRExposureBlended") {
                         options.outputLDRExposureBlended = (value == "true");
+                    } else if (var == "#hugin_outputLDRExposureLayersFused") {
+                        options.outputLDRExposureLayersFused = (value == "true");
                     } else if (var == "#hugin_outputHDRBlended") {
                         options.outputHDRBlended = (value == "true");
                     } else if (var == "#hugin_outputHDRLayers") {
@@ -2320,6 +2325,7 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
 #ifdef __unix__
                     // reset locale
                     setlocale(LC_NUMERIC,old_locale);
+                    free(old_locale);
 #endif
                     return false;
                 } else {
@@ -2356,6 +2362,7 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
     #ifdef __unix__
                 // reset locale
                 setlocale(LC_NUMERIC,old_locale);
+                free(old_locale);
     #endif
                 return false;
             }
@@ -2397,6 +2404,11 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
     if (optvec.size() != images.size()) {
         optvec = OptimizeVector(images.size());
     }
+#ifdef __unix__
+    // reset locale
+    setlocale(LC_NUMERIC,old_locale);
+    free(old_locale);
+#endif
     return true;
 }
 
