@@ -3,7 +3,7 @@
  *
  *  @author Pablo d'Angelo <pablo.dangelo@web.de>
  *
- *  $Id: PanoramaOptions.h 3623 2009-02-02 21:54:35Z dangelo $
+ *  $Id: PanoramaOptions.h 4358 2009-09-10 05:06:53Z yuv $
  *
  *  This is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -34,10 +34,6 @@
 //#include <math.h>
 #include <vigra/diff2d.hxx>
 
-
-
-#if 1
-#ifdef HasPANO13
 #include <vigra/windows.h>
 
 extern "C" {
@@ -73,9 +69,7 @@ extern "C" {
 #endif
 
     }
-#endif
 
-#endif
 //
 //#include "PT/PanoImage.h"
 
@@ -195,9 +189,7 @@ class PanoramaOptions
         virtual void reset()
         {
             m_projectionFormat = EQUIRECTANGULAR;
-#ifdef HasPANO13
             panoProjectionFeaturesQuery(m_projectionFormat, &m_projFeatures);
-#endif
             m_hfov = 360;
             m_size = vigra::Size2D(3000, 1500);
             m_roi = vigra::Rect2D(m_size);
@@ -216,6 +208,7 @@ class PanoramaOptions
             blendMode = ENBLEND_BLEND;
             hdrMergeMode = HDRMERGE_AVERAGE;
             remapper = NONA;
+            remapUsingGPU = false;
             saveCoordImgs = false;
             huberSigma = 2;
             photometricHuberSigma = 2/255.0;
@@ -365,6 +358,7 @@ class PanoramaOptions
         BlendingMechanism blendMode;
         HDRMergeType hdrMergeMode;
         Remapper remapper;
+        bool remapUsingGPU;
 
         bool saveCoordImgs;
 
@@ -379,8 +373,9 @@ class PanoramaOptions
         bool outputLDRBlended;         ///< save blended panorama (LDR)
         bool outputLDRLayers;          ///< save remapped layers (LDR)
         bool outputLDRExposureRemapped;///< save remapped layers (no exposure adjustment)
-        bool outputLDRExposureLayers;  ///< save blended exposure layers (no exposure adjustment)
-        bool outputLDRExposureBlended; ///< save blended exposure layers (no exposure adjustment)
+        bool outputLDRExposureLayers;  ///< save blended exposure layers, do not perform fusion (no exposure adjustment)
+        bool outputLDRExposureLayersFused; ///< save blended exposure layers which are then fused (no exposure adjustment)
+        bool outputLDRExposureBlended; ///< save blended exposure layers created from fused image stacks (no exposure adjustment)
         bool outputHDRBlended;         ///< save blended panorama (HDR)
         bool outputHDRLayers;          ///< save remapped layers (HDR)
         bool outputHDRStacks;          ///< save image stacks (HDR)
@@ -402,9 +397,7 @@ class PanoramaOptions
         // choose pixel type for output images.
         std::string outputPixelType;
 
-    #ifdef HasPANO13
         pano_projection_features m_projFeatures;
-    #endif
 
     private:
         static const std::string fileformatNames[];
