@@ -8,7 +8,7 @@
  *
  * !! from PanoImage.h 1970
  *
- *  $Id: SrcPanoImage.cpp 3944 2009-06-17 05:34:34Z tmodes $
+ *  $Id: SrcPanoImage.cpp 4113 2009-07-27 05:30:19Z tmodes $
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -142,6 +142,7 @@ void SrcPanoImage::setDefaults()
 
     m_exifCropFactor = 0;
     m_exifFocalLength = 0;
+    m_exifFocalLength35 = 0;
     m_exifOrientation = 0;
     m_exifAperture = 0;
     m_exifDistance = 0;
@@ -246,6 +247,7 @@ bool SrcPanoImage::operator==(const SrcPanoImage & other) const
              m_exifMake == other.m_exifMake &&
              m_exifCropFactor == other.m_exifCropFactor &&
              m_exifFocalLength == other.m_exifFocalLength &&
+             m_exifFocalLength35 == other.m_exifFocalLength35 &&
              m_exifOrientation == other.m_exifOrientation &&
              m_exifAperture == other.m_exifAperture &&
              m_exifISO == other.m_exifISO &&
@@ -601,13 +603,20 @@ bool SrcPanoImage::readEXIF(double & focalLength, double & cropFactor, double &
     }
     getExiv2Value(exifData,"Exif.Photo.SubjectDistance", subjectDistance);
 
+    std::string captureDate;
+    getExiv2Value(exifData,"Exif.Image.DateTime",captureDate);
+
+
     // store some important EXIF tags for later usage.
     setExifFocalLength(focalLength);
+    setExifFocalLength35(eFocalLength35);
     setExifCropFactor(cropFactor);
     setExifOrientation(roll);
     setExifAperture(photoFNumber);
     setExifISO(isoSpeed);
     setExifDistance(subjectDistance);
+    setExifDate(captureDate);
+    setExifExposureTime(exposureTime);
 
     DEBUG_DEBUG("Results for:" << filename);
     DEBUG_DEBUG("Focal Length: " << getExifFocalLength());
@@ -755,5 +764,19 @@ bool SrcPanoImage::getExiv2Value(Exiv2::ExifData& exifData, std::string keyName,
         return false;
     }
 }
+
+
+bool SrcPanoImage::getExiv2Value(Exiv2::ExifData& exifData, std::string keyName, std::string & value)
+{
+    Exiv2::ExifKey key(keyName);
+    Exiv2::ExifData::iterator itr = exifData.findKey(key);
+    if (itr != exifData.end()) {
+        value = itr->toString();
+        DEBUG_DEBUG("" << keyName << ": " << value);
+        return true;
+    } else {
+        return false;
+    }
+}
     
 } // namespace
